| Title: | Compare and Merge Two Files with a 'Shiny' App |
|---|---|
| Description: | A 'Shiny' app allowing to compare and merge two files, with syntax highlighting for several coding languages. |
| Authors: | Stéphane Laurent [aut, cre], Jamie Peabody [ctb, cph] (Mergely), Marijn Haverbeke [ctb, cph] (CodeMirror), Leandro Vital [ctb, cph] (Bootstrap Flash Alert), Daniel Eden [ctb, cph] (animate.css) |
| Maintainer: | Stéphane Laurent <[email protected]> |
| License: | GPL-3 |
| Version: | 0.2.0 |
| Built: | 2026-05-18 08:07:46 UTC |
| Source: | https://github.com/stla/shinymergely |
Launch a Shiny app allowing to compare and merge two files.
shinyMergely()shinyMergely()
if(interactive()){ shinyMergely() }if(interactive()){ shinyMergely() }