Welcome to ClientVPS Mirrors

Help for package shinyMergely
Type: Package
Title: Compare and Merge Two Files with a 'Shiny' App
Version: 0.2.0
Description: A 'Shiny' app allowing to compare and merge two files, with syntax highlighting for several coding languages.
URL: https://github.com/stla/shinyMergely
BugReports: https://github.com/stla/shinyMergely/issues
License: GPL-3
Encoding: UTF-8
Imports: shiny
Suggests: shinyjqui, shinythemes, tools, uchardet
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2022-01-24 11:05:21 UTC; SDL96354
Author: Stéphane Laurent [aut, cre], Jamie Peabody [ctb, cph] (Mergely), Marijn Haverbeke [ctb, cph] (CodeMirror), Leandro Vital [ctb, cph] (Bootstrap Flash Alert), Daniel Eden [ctb, cph] (animate.css)
Maintainer: Stéphane Laurent <laurent_step@outlook.fr>
Repository: CRAN
Date/Publication: 2022-01-24 11:40:02 UTC

Shiny Mergely

Description

Launch a Shiny app allowing to compare and merge two files.

Usage

shinyMergely()

Examples

if(interactive()){
  shinyMergely()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.